Index: src/objects.h |
=================================================================== |
--- src/objects.h (revision 3266) |
+++ src/objects.h (working copy) |
@@ -3156,9 +3156,12 @@ |
// [compilation]: how the the script was compiled. |
DECL_ACCESSORS(compilation_type, Smi) |
- // [line_ends]: array of line ends positions. |
- DECL_ACCESSORS(line_ends, Object) |
+ // [line_ends]: FixedArray of line ends positions. |
+ DECL_ACCESSORS(line_ends_fixed_array, Object) |
+ // [line_ends]: JSArray of line ends positions. |
+ DECL_ACCESSORS(line_ends_js_array, Object) |
+ |
// [eval_from_function]: for eval scripts the funcion from which eval was |
// called. |
DECL_ACCESSORS(eval_from_function, Object) |
@@ -3187,8 +3190,11 @@ |
static const int kWrapperOffset = kContextOffset + kPointerSize; |
static const int kTypeOffset = kWrapperOffset + kPointerSize; |
static const int kCompilationTypeOffset = kTypeOffset + kPointerSize; |
- static const int kLineEndsOffset = kCompilationTypeOffset + kPointerSize; |
- static const int kIdOffset = kLineEndsOffset + kPointerSize; |
+ static const int kLineEndsFixedArrayOffset = |
+ kCompilationTypeOffset + kPointerSize; |
+ static const int kLineEndsJSArrayOffset = |
+ kLineEndsFixedArrayOffset + kPointerSize; |
+ static const int kIdOffset = kLineEndsJSArrayOffset + kPointerSize; |
static const int kEvalFromFunctionOffset = kIdOffset + kPointerSize; |
static const int kEvalFrominstructionsOffsetOffset = |
kEvalFromFunctionOffset + kPointerSize; |